API Reference
=============

Merge
-----

.. automodule:: ocdsmerge.merge
   :members:
   :undoc-members:
   :special-members:
   :exclude-members: __dict__,__module__,__weakref__

Rules
-----

.. automodule:: ocdsmerge.rules
   :members:
   :undoc-members:

Flatten
-------

.. automodule:: ocdsmerge.flatten
   :members:
   :undoc-members:

Utilities
---------

.. automodule:: ocdsmerge.util
   :members:
   :undoc-members:

Exceptions
----------

.. autoexception:: ocdsmerge.exceptions.OCDSMergeError
.. autoexception:: ocdsmerge.exceptions.MissingDateKeyError
.. autoexception:: ocdsmerge.exceptions.NonObjectReleaseError
.. autoexception:: ocdsmerge.exceptions.NullDateValueError
.. autoexception:: ocdsmerge.exceptions.NonStringDateValueError
.. autoexception:: ocdsmerge.exceptions.InconsistentTypeError
.. autoexception:: ocdsmerge.exceptions.OCDSMergeWarning
.. autoexception:: ocdsmerge.exceptions.DuplicateIdValueWarning
